@@ -464,7 +464,7 @@ class AddGitlabLinks(object):
                 if title:
                     title = cgi.escape(title, quote=True)
                     if not isinstance(title, unicode):
-                        title = title.decode('utf-8', 'replace')
+                        title = title.decode('utf-8', errors='replace')
                     return (
                         u'<a href="https://gitlab.cern.ch/{0}/'
                         u'merge_requests/{1}" data-toggle="tooltip" '
