@@ -90,7 +90,7 @@ def _list_http(url):
                 self._text = ''
 
     parser = ListHTMLParser()
-    parser.feed(urlopen(url).read().decode())
+    parser.feed(urlopen(url).read().decode('utf-8', errors='replace'))
     return parser.data
 
 
@@ -100,7 +100,7 @@ def _list_ssh(url):
     '''
     host, path = url.split(':', 1)
     proc = Popen(['ssh', host, 'ls -a1 %r' % path], stdout=PIPE)
-    return proc.communicate()[0].decode().splitlines()
+    return proc.communicate()[0].decode('utf-8', errors='replace').splitlines()
 
 
 def _url_protocol(url):
@@ -620,7 +620,8 @@ class Script(PlainScript):
                 command = ['patch', '-p1', '-f', '-i', 'slot.patch']
                 proc = Popen(command, cwd=dest, stdout=PIPE, stderr=STDOUT)
                 out, _ = proc.communicate()
-                self.log.debug('output of %s:\n%s', command, out.decode())
+                self.log.debug('output of %s:\n%s', command,
+                               out.decode('utf-8', errors='replace'))
 
             if index_installed:
                 fixGlimpseIndexes(
